@@ -12,7 +12,7 @@ our @ISA = qw(Exporter);
 
 BEGIN {
     use XSLoader;
-    $VERSION = '1.17';
+    $VERSION = '1.18';
     XSLoader::load('Math::Clipper', $VERSION);
 }
 
@@ -24,7 +24,7 @@ our %EXPORT_TAGS = (
     polyfilltypes => [qw/PFT_EVENODD PFT_NONZERO PFT_POSITIVE PFT_NEGATIVE/],
     jointypes     => [qw/JT_MITER JT_ROUND JT_SQUARE/],
     utilities       => [qw/area offset is_counter_clockwise orientation integerize_coordinate_sets unscale_coordinate_sets
-                    simplify_polygon simplify_polygons/],
+                    simplify_polygon simplify_polygons int_offset ex_int_offset ex_int_offset2/],
 );
 
 $EXPORT_TAGS{all} = [ map { @$_ } values %EXPORT_TAGS ];
@@ -453,6 +453,29 @@ it if it is important in your application.
 
 Join type can be one of C<JT_MITER>, C<JT_ROUND> or C<JT_SQUARE>.
 
+=head2 int_offset
+
+    my $offset_polygons = int_offset($polygons, $distance, $scale, $jointype, $miterlimit);
+
+This function is a faster replacement for offset() when input coordinates are integers. 
+If floats are supplied to it, their decimal digits will be truncated so the offset might 
+work on invalid geometry (truncation can lead to self-intersecting polygons). Be sure to
+only use this one if your input polygons only have integer coordinates.
+
+=head2 ex_int_offset
+
+    my $offset_expolygons = ex_int_offset($polygons, $distance, $scale, $jointype, $miterlimit);
+
+This function works like int_offset() but it does a UNION operation on the resulting polygons
+and returns an arrayref of ExPolygons.
+
+=head2 ex_int_offset2
+
+    my $offset_expolygons = ex_int_offset2($polygons, $distance1, $distance2, $scale, $jointype, $miterlimit);
+
+This function works like ex_int_offset() but it does two consecutive offsets with the given 
+distances before performing the UNION operation.
+
 =head2 area
 
 Returns the signed area of a single polygon.
